void track_options();
void move_TB6612FNG();

void setup_TB6612FNG(){
  pinMode(aIn1, OUTPUT);
  pinMode(aIn2, OUTPUT);
  pinMode(aPWM, OUTPUT);
  pinMode(bIn1, OUTPUT);
  pinMode(bIn2, OUTPUT);
  pinMode(bPWM, OUTPUT);
  pinMode(cIn1, OUTPUT);
  pinMode(cIn2, OUTPUT);
  pinMode(cPWM, OUTPUT);
  pinMode(dIn1, OUTPUT);
  pinMode(dIn2, OUTPUT);
  pinMode(dPWM, OUTPUT);
  stop_TB6612FNG(); }       // brake  

void stop_TB6612FNG(){        // initialize or stop TB6612FNG
  digitalWrite(aIn1, HIGH);
  digitalWrite(aIn2, HIGH);
  digitalWrite(bIn1, HIGH);
  digitalWrite(bIn2, HIGH);
  digitalWrite(cIn1, HIGH);
  digitalWrite(cIn2, HIGH);
  digitalWrite(dIn1, HIGH);
  digitalWrite(dIn2, HIGH); }

void safeRover(){ //enable LOW, free run motors
  digitalWrite(aPWM, LOW);
  digitalWrite(bPWM, LOW);
  digitalWrite(cPWM, LOW);
  digitalWrite(dPWM, LOW);}


uint8_t tracknumber = 0x03;
uint8_t track_options(uint8_t dat){
    tracknumber = dat;
    return tracknumber; }

void move_TB6612FNG(uint8_t * dat){

  switch (tracknumber){
    case 0x01: 
      run_TB6612FNG(dat[3], aIn1, aIn2);  // configure H-bridge for motor A (left)
      analogWrite(aPWM, dat[4]);          // set speed motor A (left motor)
  
      run_TB6612FNG(dat[5], bIn1, bIn2);  // configure H-bridge for motor B (right)
      analogWrite(bPWM, dat[6]);          // set speed motor B (right motor)
  
      digitalWrite(cPWM, LOW);
      digitalWrite(dPWM, LOW);
      break;

    case 0x02:
      digitalWrite(aPWM, LOW);
      digitalWrite(bPWM, LOW);
      
      run_TB6612FNG(dat[3], cIn1, cIn2);
      analogWrite(cPWM, dat[4]);
      
      run_TB6612FNG(dat[5], dIn1, dIn2);
      analogWrite(dPWM, dat[6]);
      break;

    case 0x03:
      run_TB6612FNG(dat[3], aIn1, aIn2); 
      analogWrite(aPWM, dat[4]);     
      
      run_TB6612FNG(dat[5], bIn1, bIn2);  
      analogWrite(bPWM, dat[6]);   
    
      run_TB6612FNG(dat[3], cIn1, cIn2);
      analogWrite(cPWM, dat[4]);
      
      run_TB6612FNG(dat[5], dIn1, dIn2);
      analogWrite(dPWM, dat[6]);
      break; } 
}


void run_TB6612FNG(uint8_t dir, uint8_t pin_in1, uint8_t pin_in2)
{
  uint8_t IN1;  // see TB6612FNG Control Function Truth Table atIf nothing  bottom of page
  uint8_t IN2;
  
  switch (dir)  // set dir = dat[1] for motor A (left) 
  {
    case 1:  // FORWARD
      IN1 = HIGH;
      IN2 = LOW;
      break;
    case 2:  // BACKWARD
      IN1 = LOW;
      IN2 = HIGH;
      break;
    case 3:  // BRAKE
      IN1 = HIGH;
      IN2 = HIGH;
      break;
    case 4:  // RELEASE
      IN1 = LOW;
      IN2 = LOW;
      break;
    default:
      IN1 = LOW;
      IN2 = LOW;
  }
  digitalWrite(pin_in1, IN1);
  digitalWrite(pin_in2, IN2); 
}


/*
Arxterra Command Format
  left motor A   
    dat[3]
    FORWARD = index 1, BACKWARD = index 2, BRAKE = index 3, RELEASE = index 4
    dat[4]
    0 - 255
  right motor B   
    dat[5]
    FORWARD = index 1, BACKWARD = index 2, BRAKE = index 3, RELEASE = index 4
    dat[6]
    0 - 255
*/

/* TB6612FNG Control Functions
     Source: H-SW Control Functions found in the Datasheet on Page 4
             https://www.sparkfun.com/datasheets/Robotics/TB6612FNG.pdf
     Pin#  = IN1    IN2
     Logic = inPin1 inPin2  Mode
              0     0       OFF (High Impedance)     
              0     1       BACKWARD (CCW)
              1     0       FORWARD  (CW)
              1     1       Short brake
*/


